BlockhashQueue

Struct BlockhashQueue 

pub struct BlockhashQueue { /* private fields */ }
๐Ÿ‘ŽDeprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
Low memory overhead, so can be cloned for every checkpoint

Implementations

Source

impl BlockhashQueue

pub fn new(max_age: usize) -> Self

๐Ÿ‘ŽDeprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn last_hash(&self) -> Hash

๐Ÿ‘ŽDeprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn get_lamports_per_signature(&self, hash: &Hash) -> Option<u64>

๐Ÿ‘ŽDeprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn is_hash_valid_for_age(&self, hash: &Hash, max_age: usize) -> bool

๐Ÿ‘ŽDeprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.

Check if the age of the hash is within the specified age

pub fn get_hash_info_if_valid( &self, hash: &Hash, max_age: usize, ) -> Option<&HashInfo>

๐Ÿ‘ŽDeprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.

Get hash info for the specified hash if it is in the queue and its age of the hash is within the specified age

pub fn get_hash_age(&self, hash: &Hash) -> Option<u64>

๐Ÿ‘ŽDeprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn genesis_hash(&mut self, hash: &Hash, lamports_per_signature: u64)

๐Ÿ‘ŽDeprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn register_hash(&mut self, hash: &Hash, lamports_per_signature: u64)

๐Ÿ‘ŽDeprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn get_recent_blockhashes(&self) -> impl Iterator<Item = IterItem<'_>>

๐Ÿ‘ŽDeprecated since 1.9.0: Please do not use, will no longer be available in the future
pub fn get_max_age(&self) -> usize

๐Ÿ‘ŽDeprecated since 2.0.0: Please use solana_clock::MAX_PROCESSING_AGE