pub struct BlockhashQueue { /* private fields */ }๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Expand description
Low memory overhead, so can be cloned for every checkpoint
Implementations
Sourceimpl BlockhashQueue
impl BlockhashQueue
pub fn new(max_age: usize) -> Self
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.pub fn last_hash(&self) -> Hash
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.pub fn get_lamports_per_signature(&self, hash: &Hash) -> Option<u64>
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Sourcepub fn is_hash_valid_for_age(&self, hash: &Hash, max_age: usize) -> bool
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn is_hash_valid_for_age(&self, hash: &Hash, max_age: usize) -> bool
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Check if the age of the hash is within the specified age
Sourcepub fn get_hash_info_if_valid(
&self,
hash: &Hash,
max_age: usize,
) -> Option<&HashInfo>
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.
pub fn get_hash_info_if_valid( &self, hash: &Hash, max_age: usize, ) -> Option<&HashInfo>
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.Get hash info for the specified hash if it is in the queue and its age of the hash is within the specified age
pub fn get_hash_age(&self, hash: &Hash) -> Option<u64>
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.pub fn genesis_hash(&mut self, hash: &Hash, lamports_per_signature: u64)
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.pub fn register_hash(&mut self, hash: &Hash, lamports_per_signature: u64)
๐Deprecated since 3.1.0: This crate has been marked for formal inclusion in the Agave Unstable API. From v4.0.0 onward, the
agave-unstable-api crate feature must be specified to acknowledge use of an interface that may break without warning.pub fn get_recent_blockhashes(&self) -> impl Iterator<Item = IterItem<'_>>
๐Deprecated since 1.9.0: Please do not use, will no longer be available in the future
pub fn get_max_age(&self) -> usize
๐Deprecated since 2.0.0: Please use
solana_clock::MAX_PROCESSING_AGETrait Implementations
Sourceimpl Clone for BlockhashQueue
impl Clone for BlockhashQueue
Sourcefn clone(&self) -> BlockhashQueue
fn clone(&self) -> BlockhashQueue
Returns a duplicate of the value. Read more
1.0.0 ยท Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BlockhashQueue
impl Debug for BlockhashQueue
Sourceimpl Default for BlockhashQueue
impl Default for BlockhashQueue
Sourceimpl<'de> Deserialize<'de> for BlockhashQueue
impl<'de> Deserialize<'de> for BlockhashQueue
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for BlockhashQueue
impl PartialEq for BlockhashQueue
Sourceimpl Serialize for BlockhashQueue
impl Serialize for BlockhashQueue
impl Eq for BlockhashQueue
impl StructuralPartialEq for BlockhashQueue